"use strict";

(function ($) {
  var URTFA = {
    resend_limit: 0,
    incorrect_limit: 0,

    init: function () {
      URTFA.init_values();
      URTFA.init_triggers();
      URTFA.init_render();
    },

    init_values: function () {
      if ("" == user_registration_tfa_parameters.otp_resend_limit) {
        URTFA.resend_limit = 0;
      } else {
        URTFA.resend_limit = parseInt(
          user_registration_tfa_parameters.otp_resend_limit
        );
      }

      if ("" == user_registration_tfa_parameters.otp_incorrect_limit) {
        URTFA.incorrect_limit = 0;
      } else {
        URTFA.incorrect_limit = parseInt(
          user_registration_tfa_parameters.otp_incorrect_limit
        );
      }
    },

    init_triggers: function () {
      $("#user-registration-tfa-otp-submit-btn").on("click", function (e) {
        e.preventDefault();
        e.stopPropagation();
        URTFA.submit();
      });

      $("#user-registration-tfa-otp-resend-btn").on("click", function (e) {
        e.preventDefault();
        e.stopPropagation();
        URTFA.resend_otp();
      });
    },

    /**
     * Render initial values and message.
     */
    init_render: function () {
      if (URTFA.incorrect_limit > 0) {
        URTFA.show_message(
          user_registration_tfa_parameters.otp_sent_message,
          "user-registration-message"
        );
      } else {
        URTFA.show_message(
          user_registration_tfa_parameters.otp_submit_limit_message,
          "user-registration-error"
        );
      }
      URTFA.render_values();
    },

    /**
     * Show message to user in message box.
     *
     * @param {string} msg Message to display
     */
    show_message: function (msg = "", elementClass = "user-registration-info") {
      var el = $("<li></li>");

      el.html(msg);

      $("#user-registration-tfa-message-container")
        .removeClass()
        .addClass(elementClass)
        .empty()
        .append(el);
    },

    /**
     * Display values for the Invalid attempts limit and resend limit left.
     */
    render_values: function () {
      $("#user-registration-tfa-resend-limit").html(
        " (" + URTFA.resend_limit + ")"
      );
      $("#user-registration-tfa-attempts-left-counter").html(
        URTFA.incorrect_limit
      );

      if (URTFA.incorrect_limit <= 0) {
        URTFA.hold_user_login();
      }

      if (URTFA.resend_limit <= 0) {
        $("#user-registration-tfa-otp-resend-btn").prop("disabled", true);
      }
    },

    /**
     * Submit the Entered OTP.
     *
     * @returns void
     */
    submit: function () {
      var spinner = $("#user-registration-tfa-spinner").addClass(
        "ur-front-spinner"
      );
      var submit_btn = $("#user-registration-tfa-otp-submit-btn").prop(
        "disabled",
        true
      );

      var resend_btn = $("#user-registration-tfa-otp-resend-btn").attr(
        "disabled",
        true
      );

      if (URTFA.incorrect_limit <= 0) {
        URTFA.hold_user_login();
        return;
      }

      var otp_code = $("#user-registration-tfa-otp-field").val();

      $.ajax({
        type: "POST",
        url: user_registration_tfa_parameters.ajax_url,
        data: {
          action: user_registration_tfa_parameters.otp_submit_action,
          security: user_registration_tfa_parameters.otp_submit_nonce,
          otp_code: otp_code,
          user_id: user_registration_tfa_parameters.user_id,
        },
        success: function (response) {
          if (true == response.success && "verified" == response.data.status) {
            if (response.data.redirect) {
              URTFA.show_message(
                response.data.message,
                "user-registration-message"
              );
              window.location.replace(response.data.redirect);
            }
          } else {
            URTFA.incorrect_limit--;
            URTFA.show_message(
              response.data.message,
              "user-registration-error"
            );
            submit_btn.prop("disabled", false);
            if ( 0 < URTFA.resend_limit ) {
              resend_btn.prop("disabled", false);
            }
          }
          spinner.removeClass("ur-front-spinner");
          URTFA.render_values();
        },
        dataType: "json",
      });
    },

    /**
     * Send Resend OTP request to server.
     *
     * @returns void.
     */
    resend_otp: function () {
      var resend_btn = $("#user-registration-tfa-otp-resend-btn").prop(
        "disabled",
        true
      );

      if (URTFA.resend_limit <= 0) {
        URTFA.show_message(
          user_registration_tfa_parameters.otp_resend_limit_message,
          "user-registration-error"
        );
        return;
      }

      $.ajax({
        type: "POST",
        url: user_registration_tfa_parameters.ajax_url,
        action: user_registration_tfa_parameters.otp_resend_action,
        data: {
          action: user_registration_tfa_parameters.otp_resend_action,
          security: user_registration_tfa_parameters.otp_resend_nonce,
          user_id: user_registration_tfa_parameters.user_id,
        },
        success: function (res) {
          URTFA.show_message(res.data.message, "user-registration-message");
          resend_btn.prop("disabled", false);
        },
        dataType: "json",
      });

      URTFA.resend_limit--;
      URTFA.render_values();
    },

    /**
     * Prevent user from logging in.
     */
    hold_user_login: function() {
      $("#user-registration-tfa-otp-field").prop("disabled", true);
      $("#user-registration-tfa-otp-resend-btn").prop("disabled", true);
      $("#user-registration-tfa-otp-submit-btn").prop("disabled", true);

      URTFA.redirect_to_login_page();
    },

    /**
     * Redirect user to login page.
     *
     * @param {int} start_time Timeout beore redirecting to login page.
     */
    redirect_to_login_page: function( start_time = 0 ) {
      if ( user_registration_tfa_parameters.login_page_url ) {
        setTimeout( function() {
          URTFA.show_message('Redirecting to login page . . .', 'user-registration-info');
          window.location.replace(user_registration_tfa_parameters.login_page_url);
        }, start_time*1000 );
      }
    }
  };

  $(document).ready(function () {
    URTFA.init();
  });
})(jQuery);
