<?php
/**
 * UserRegistrationTwoFactorAuthentication Admin.
 *
 * @class    Admin
 * @package  UserRegistrationTwoFactorAuthentication/Admin
 * @category Admin
 * @author   WPEverest
 * @since  1.0.0
 */

namespace WPEverest\UserRegistration\TwoFactorAuthentication\Admin;

use WPEverest\UserRegistration\TwoFactorAuthentication\Admin\Settings\Emails\UR_Settings_OTP_Email;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Admin Class
 */
class Admin {

	/**
	 * Hook in tabs.
	 */
	public function __construct() {
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts' ) );
		add_action( 'admin_init', array( $this, 'admin_redirects' ) );
		add_action( 'admin_init', array( $this, 'add_rewrite_rules' ) );

		// add actions and filters.
		add_filter( 'user_registration_get_settings_pages', array( $this, 'add_user_registration_tfa_setting' ), 10, 1 );
		add_filter( 'user_registration_email_classes', array( $this, 'add_email_settings' ), 10, 1 );

	}

	/**
	 * Adds settings for Two Factor Authentication.
	 *
	 * @param array $settings Displays settings for Two Factor Authentication.
	 *
	 * @return array $settings
	 */
	public function add_user_registration_tfa_setting( $settings ) {
		if ( class_exists( 'UR_Settings_Page' ) ) {
			$settings[] = include_once dirname( __FILE__ ) . '/Settings/Settings.php';
		}

		return $settings;
	}

	/**
	 * Add OTP Email Settings to the Email tab.
	 *
	 * @param [array] $emails Email Settings array.
	 * @return array
	 */
	public function add_email_settings( $emails ) {
		$emails['UR_Settings_OTP_Email'] = new UR_Settings_OTP_Email();

		return $emails;
	}

	/**
	 * Handle redirects to setup/welcome page after install and updates.
	 *
	 * For setup wizard, transient must be present, the user must have access rights, and we must ignore the network/bulk plugin updaters.
	 */
	public function admin_redirects() {
		// Setup wizard redirect.
		if ( get_transient( '_ur2fa_activation_redirect' ) ) {
			delete_transient( '_ur2fa_activation_redirect' );

			if ( ( is_network_admin() || isset( $_GET['activate-multi'] ) ) || ! current_user_can( 'manage_options' ) || apply_filters( 'user_registration_tfa_prevent_activation_redirect', false ) ) {
				return;
			}

			$message = ur2fa_is_compatible();
			if ( 'YES' === $message ) {
				// If the user needs to install, send them to the settings page.
				wp_safe_redirect( admin_url( 'admin.php?page=user-registration-settings&tab=user-registration-two-factor-authentication' ) );
				exit;
			}
		}
	}

	/**
	 * Admin Scripts.
	 */
	public function admin_scripts() {

		$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		wp_enqueue_script(
			'user-registration-two-factor-authentication',
			plugins_url( '/assets/js/two-factor-authentication-admin' . $suffix . '.js', UR2FA_PLUGIN_FILE ),
			array( 'jquery' ),
			UR2FA_VERSION,
			true
		);
	}

	/**
	 * Add Endpoints and Flush.
	 */
	public function add_rewrite_rules() {
		add_rewrite_endpoint( 'otp-login', EP_ALL );
		add_rewrite_endpoint( 'otp', EP_ALL );
		flush_rewrite_rules();
	}
}

return new Admin();
