<?php
/**
 * Configure Email
 *
 * @package  UR_Settings_OTP_Email
 * @extends  UR_Settings_Email
 */

namespace WPEverest\UserRegistration\TwoFactorAuthentication\Admin\Settings\Emails;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'UR_Settings_OTP_Email', false ) ) :
	/**
	 * UR_Settings_OTP_Email Class.
	 */
	class UR_Settings_OTP_Email {

		/**
		 * Unique Email Id.
		 *
		 * @var string
		 */
		public $id = '';

		/**
		 * Email Title.
		 *
		 * @var string
		 */
		public $title = '';

		/**
		 * Email description.
		 *
		 * @var string
		 */
		public $description = '';

		/**
		 * Constructor.
		 */
		public function __construct() {
			$this->id          = 'otp_email';
			$this->title       = __( 'OTP Email', 'user-registration-two-factor-authentication' );
			$this->description = __( 'Email sent to the user containing the one time password to login.', 'user-registration-two-factor-authentication' );
		}

		/**
		 * Get settings
		 *
		 * @return array
		 */
		public function get_settings() {

			$settings = apply_filters(
				'user_registration_tfa_otp_email',
				array(
					'title'    => __( 'Emails', 'user-registration-two-factor-authentication' ),
					'sections' => array(
						'otp_email' => array(
							'title'     => __( 'OTP Email', 'user-registration-two-factor-authentication' ),
							'type'      => 'card',
							'desc'      => '',
							'back_link' => ur_back_link( __( 'Return to emails', 'user-registration-two-factor-authentication' ), admin_url( 'admin.php?page=user-registration-settings&tab=email' ) ),
							'settings'  => array(
								array(
									'title'    => __( 'Enable this email', 'user-registration-two-factor-authentication' ),
									'desc'     => __( 'Enable this email sent to the user providing the otp code.', 'user-registration-two-factor-authentication' ),
									'id'       => 'user_registration_tfa_enable_otp_email',
									'default'  => 'yes',
									'type'     => 'checkbox',
									'autoload' => false
								),
								array(
									'title'    => __( 'Email Subject', 'user-registration-two-factor-authentication' ),
									'desc'     => __( 'The email subject you want to customize.', 'user-registration-two-factor-authentication' ),
									'id'       => 'user_registration_tfa_otp_email_subject',
									'type'     => 'text',
									'default'  => __( 'OTP Verification Code - {{blog_info}}', 'user-registration-two-factor-authentication' ),
									'css'      => 'min-width: 350px;',
									'desc_tip' => true
								),
								array(
									'title'    => __( 'Email Content', 'user-registration-two-factor-authentication' ),
									'desc'     => __( 'The email content you want to customize.', 'user-registration-two-factor-authentication' ),
									'id'       => 'user_registration_tfa_otp_email',
									'type'     => 'tinymce',
									'default'  => $this->get_otp_email(),
									'css'      => 'min-width: 350px;',
									'desc_tip' => true
								)
							)
						)
					)
				)
			);

			return apply_filters( 'user_registration_get_settings_' . $this->id, $settings );
		}

		/**
		 * Email Format.
		 */
		public function get_otp_email() {

			$message = apply_filters(
				'user_registration_get_otp_email',
				sprintf(
					__(
						'Hi {{username}}, <br/>

						Your One Time Password (OTP) is : <code><h2>{{otp_code}}</h2></code>

						Enter this code to login to your account. <br/>

						Note: This code expires in {{otp_expiry_time}} minutes.<br/>

						Thank You!',
						'user-registration-two-factor-authentication'
					)
				)
			);

			return $message;
		}
	}
endif;

return new UR_Settings_OTP_Email();
