<?php
/**
 * UserRegistrationTwoFactorAuthentication Settings class.
 *
 * @package UserRegistrationTwoFactorAuthentication/Settings
 * @author  WPEverest
 * @since   v1.0.0
 */

namespace WPEverest\UserRegistration\TwoFactorAuthentication\Admin\Settings;

use \UR_Settings_Page;
use \UR_Admin_Settings;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'Settings' ) ) :

	/**
	 * User_Registration_Two_Factor_Authentication_Settings Setting
	 */
	class Settings extends UR_Settings_Page {

		/**
		 * Constructor.
		 */
		public function __construct() {
			$this->id    = 'user-registration-two-factor-authentication';
			$this->label = esc_html__( 'Two Factor Authentication', 'user-registration-two-factor-authentication' );

			$this->init_hooks();

		}

		/**
		 * Initialize hooks.
		 *
		 * @since 1.0.0
		 *
		 * @return void
		 */
		private function init_hooks() {
			add_filter( 'user_registration_settings_tabs_array', array( $this, 'add_settings_page' ), 20 );
			add_action( 'user_registration_settings_' . $this->id, array( $this, 'output' ) );
			add_action( 'user_registration_settings_save_' . $this->id, array( $this, 'save' ) );

			add_filter(
				'user_registration_admin_settings_sanitize_option_user_registration_tfa_enable_disable',
				array(
					$this,
					'validate_my_account_is_set'
				)
			);
		}

		/**
		 * Add this page to settings.
		 *
		 * @param  array $pages Pages.
		 * @return mixed
		 */
		public function add_settings_page( $pages ) {
			$pages[ $this->id ] = $this->label;

			return $pages;
		}

		/**
		 * Get Settings Array.
		 *
		 * @param string $current_section Current Section.
		 * @return array
		 */
		public function get_settings( $current_section = '' ) {
			$settings = ur2fa_settings();
			return apply_filters( 'user_registration_tfa_settings' . $this->id, $settings );
		}

		/**
		 * Outputs Page
		 *
		 * @return void
		 */
		public function output() {
			global $current_section, $hide_save_button;

			$settings = $this->get_settings( $current_section );

			UR_Admin_Settings::output_fields( $settings );
		}

		/**
		 * Save settings
		 */
		public function save() {

			global $current_section;

			$settings = $this->get_settings( $current_section );

			UR_Admin_Settings::save_fields( $settings );

		}

		/**
		 * Check if my account page is set on site when trying to enable two factor authentication.
		 *
		 * @param [string] $value Setting Value.
		 * @return string
		 */
		public function validate_my_account_is_set( $value ) {
			if ( 'yes' === $value ) {
				if ( empty( ur_get_my_account_url() ) ) {
					$err_msg = esc_html__( 'Please setup My Account Page first to use Two Factor Authentication.', 'user-registration-two-factor-authentication' );

					UR_Admin_Settings::add_error( $err_msg );

					$value = 'no';
				}
			}
			return $value;
		}
	}
endif;
return new Settings();
